# pySISF

This repositories implements tools for running

## Installation

pySISF can be installed using `pip`:

```pip install pySISF```

## Template Citation

This project's layout and CI are based on the great Python project template provided by [Microsoft](https://github.com/microsoft/python-package-template).